@@ -48,11 +48,16 @@
 #' ##################################################
 #'
 #' # Pedigrees (a) - (d)
+#' ped.a = linearPed(3)
+#' ped.b = halfCousinPed(0, removal = 1)
+#' ped.c = cousinPed(1)
+#' ped.d = doubleCousins(1, 1, half1 = TRUE, half2 = TRUE)
+#'
 #' peds = list(
-#'   a = list(ped = linearPed(3), ids = c(1,7)),
-#'   b = list(ped = halfCousinPed(0, 1), ids = c(3,7)),
-#'   c = list(ped = cousinPed(1), ids = c(5,8)),
-#'   d = list(ped = doubleCousins(1, 1, half1 = TRUE, half2 = TRUE), ids = c(5,9))
+#'   a = list(ped = ped.a, ids = c(1,7)),
+#'   b = list(ped = ped.b, ids = leaves(ped.b)),
+#'   c = list(ped = ped.c, ids = leaves(ped.c)),
+#'   d = list(ped = ped.d, ids = leaves(ped.d))
 #' )
 #'
 #' # Recombination values
@@ -63,7 +68,7 @@
 #'
 #' # Plot
 #' matplot(rseq, kvals, type = "l", lwd = 2)
-#' legend("topright", names(peds), col = 1:4, lty = 1:4)
+#' legend("topright", names(peds), col = 1:4, lty = 1:4, lwd = 2)
 #'
 #' @importFrom utils combn
 #' @export
@@ -267,7 +272,6 @@ twoLocKin = function(A, B, C, D, mem, indent = 0) {
     }
   }
 
-  isFou = mem$isFounder[a]
   ANC = mem$anc
 
   # If no common ancestors, return 0
